
use v6-alpha;

role Hash--Perl6 does Map--Perl6;

# hmm, again, I think Map covers all of this...
